@@ -65,18 +65,30 @@ INTERNALERROR_INVALIDERRORCODE = 'InternalError.InvalidErrorCode'
 # 内部服务错误，请联系腾讯云工程师进一步排查。
 INTERNALERROR_PROXYSERVER = 'InternalError.ProxyServer'
 
+# 内部服务错误，请联系腾讯云工程师进一步排查。
+INTERNALERROR_ROUTEERROR = 'InternalError.RouteError'
+
 # SCDN服务未生效，请购买或续费SCDN套餐后重试。
 INTERNALERROR_SCDNUSERNOPACKAGE = 'InternalError.ScdnUserNoPackage'
 
 # 安全加速服务已停服，请重新购买套餐后开启。
 INTERNALERROR_SCDNUSERSUSPEND = 'InternalError.ScdnUserSuspend'
 
+# 内部数据错误，请重试或联系客服人员解决。
+INTERNALERROR_SYSTEMDBERROR = 'InternalError.SystemDBError'
+
+# 内部服务错误，请联系腾讯云工程师进一步排查。
+INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
+
 # 标签内部错误，请重试或联系客服人员解决。
 INTERNALERROR_TAGSYSTEMERROR = 'InternalError.TagSystemError'
 
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 域名启用 HTTPS 配置需保持访问端口配置-443端口为开启状态。
+INVALIDPARAMETER_ACCESSPORTOPENEDHTTPS = 'InvalidParameter.AccessPortOpenedHttps'
+
 # 域名状态不合法。
 INVALIDPARAMETER_CDNSTATUSINVALIDDOMAIN = 'InvalidParameter.CDNStatusInvalidDomain'
 
@@ -131,7 +143,7 @@ INVALIDPARAMETER_CDNCONFIGTAGREQUIRED = 'InvalidParameter.CdnConfigTagRequired'
 # 域名拥有特殊配置，需人工处理。
 INVALIDPARAMETER_CDNHOSTHASSPECIALCONFIG = 'InvalidParameter.CdnHostHasSpecialConfig'
 
-# 内部域名不允许接入。
+# 该域名为内部域名，不可接入。
 INVALIDPARAMETER_CDNHOSTINTERNALHOST = 'InvalidParameter.CdnHostInternalHost'
 
 # 错误的中间源配置。
@@ -230,6 +242,15 @@ INVALIDPARAMETER_CLSTOPICCONFLICT = 'InvalidParameter.ClsTopicConflict'
 # 内部接口错误，请重试或联系客服人员解决。
 INVALIDPARAMETER_ECDNINTERFACEERROR = 'InvalidParameter.EcdnInterfaceError'
 
+# 参数错误。
+INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
+
+# 域名所在平台不支持远程鉴权。
+INVALIDPARAMETER_REMOTEAUTHINVALIDPLATFORM = 'InvalidParameter.RemoteAuthInvalidPlatform'
+
+# 域名所在平台不支持使用https协议访问远程鉴权地址。
+INVALIDPARAMETER_REMOTEAUTHINVALIDPROTOCOL = 'InvalidParameter.RemoteAuthInvalidProtocol'
+
 # 任务已过期,无法重试。
 INVALIDPARAMETER_SCDNLOGTASKEXPIRED = 'InvalidParameter.ScdnLogTaskExpired'
 
@@ -266,6 +287,9 @@ LIMITEXCEEDED_CDNCALLINGQUERYIPTOOOFTEN = 'LimitExceeded.CdnCallingQueryIpTooOft
 # 该账号已经创建了太多主题。
 LIMITEXCEEDED_CDNCLSTOOMANYTOPICS = 'LimitExceeded.CdnClsTooManyTopics'
 
+# 缓存配置规则数超出限制。
+LIMITEXCEEDED_CDNCONFIGTOOMANYCACHERULES = 'LimitExceeded.CdnConfigTooManyCacheRules'
+
 # 域名操作过于频繁。
 LIMITEXCEEDED_CDNHOSTOPTOOOFTEN = 'LimitExceeded.CdnHostOpTooOften'
 
@@ -308,6 +332,12 @@ LIMITEXCEEDED_SCDNLOGTASKEXCEEDDAYLIMIT = 'LimitExceeded.ScdnLogTaskExceedDayLim
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 操作被拒绝。
+OPERATIONDENIED = 'OperationDenied'
+
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # 域名与系统中已存在域名存在冲突。
 RESOURCEINUSE_CDNCONFLICTHOSTEXISTS = 'ResourceInUse.CdnConflictHostExists'
 
@@ -323,12 +353,6 @@ RESOURCEINUSE_TCBHOSTEXISTS = 'ResourceInUse.TcbHostExists'
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
-# 标签键不存在。
-RESOURCENOTFOUND_CAMTAGKEYNOTEXIST = 'ResourceNotFound.CamTagKeyNotExist'
-
-# 标签不存在。
-RESOURCENOTFOUND_CAMTAGNOTEXIST = 'ResourceNotFound.CamTagNotExist'
-
 # 账号下无此域名，请确认后重试。
 RESOURCENOTFOUND_CDNHOSTNOTEXISTS = 'ResourceNotFound.CdnHostNotExists'
 
@@ -371,6 +395,9 @@ RESOURCEUNAVAILABLE_CDNHOSTEXISTSINTCB = 'ResourceUnavailable.CdnHostExistsInTcb
 # 域名被锁定。
 RESOURCEUNAVAILABLE_CDNHOSTISLOCKED = 'ResourceUnavailable.CdnHostIsLocked'
 
+# 域名不安全或为恶意域名，不可接入。
+RESOURCEUNAVAILABLE_CDNHOSTISMALICIOUS = 'ResourceUnavailable.CdnHostIsMalicious'
+
 # 域名未下线。
 RESOURCEUNAVAILABLE_CDNHOSTISNOTOFFLINE = 'ResourceUnavailable.CdnHostIsNotOffline'
 
@@ -401,6 +428,9 @@ UNAUTHORIZEDOPERATION_CDNDOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.CdnDom
 # 域名在内部系统已存在，请提工单处理。
 UNAUTHORIZEDOPERATION_CDNHOSTEXISTSININTERNAL = 'UnauthorizedOperation.CdnHostExistsInInternal'
 
+# 域名现存在风险，不可接入。
+UNAUTHORIZEDOPERATION_CDNHOSTINICPBLACKLIST = 'UnauthorizedOperation.CdnHostInIcpBlacklist'
+
 # 该域名属于其他账号，您没有权限接入。
 UNAUTHORIZEDOPERATION_CDNHOSTISOWNEDBYOTHER = 'UnauthorizedOperation.CdnHostIsOwnedByOther'
 
@@ -455,6 +485,9 @@ UNAUTHORIZEDOPERATION_CLSUNAUTHORIZED = 'UnauthorizedOperation.ClsUnauthorized'
 # 内部服务错误，请联系腾讯云工程师进一步排查。
 UNAUTHORIZEDOPERATION_CSRFERROR = 'UnauthorizedOperation.CsrfError'
 
+# 鉴权域名为空。
+UNAUTHORIZEDOPERATION_DOMAINEMPTY = 'UnauthorizedOperation.DomainEmpty'
+
 # 未授权的操作。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
@@ -464,9 +497,15 @@ UNAUTHORIZEDOPERATION_OPNOAUTH = 'UnauthorizedOperation.OpNoAuth'
 # 操作超出调用频次限制。
 UNAUTHORIZEDOPERATION_OPERATIONTOOOFTEN = 'UnauthorizedOperation.OperationTooOften'
 
+# 未授权操作。
+UNAUTHORIZEDOPERATION_UNKNOWN = 'UnauthorizedOperation.Unknown'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # 不允许操作。
 UNSUPPORTEDOPERATION_CLSNOTALLOWED = 'UnsupportedOperation.ClsNotAllowed'
 
